@@ -1,10 +1,10 @@
 package Form::Tiny::Error;
-$Form::Tiny::Error::VERSION = '2.25';
+$Form::Tiny::Error::VERSION = '2.26';
 use v5.10;
 use strict;
 use warnings;
 use Moo;
-use Types::Standard qw(Maybe Str);
+use Types::Standard qw(Maybe Str InstanceOf);
 use Types::TypeTiny qw(StringLike);
 use Carp qw(confess);
 
@@ -12,6 +12,13 @@ use overload
 	q{""} => 'as_string',
 	fallback => 1;
 
+has 'field_def' => (
+	is => 'ro',
+	isa => InstanceOf['Form::Tiny::FieldDefinition'],
+	writer => 'set_field_def',
+	predicate => 'has_field_def',
+);
+
 has 'field' => (
 	is => 'ro',
 	isa => Str,
@@ -26,6 +33,15 @@ has 'error' => (
 	builder => 'default_error',
 );
 
+sub BUILD
+{
+	my ($self) = @_;
+
+	if (!$self->field && $self->field_def) {
+		$self->set_field($self->field_def->name);
+	}
+}
+
 sub default_error
 {
 	confess 'no error message supplied';
@@ -53,7 +69,7 @@ sub as_string
 
 	# Internal use only
 	package Form::Tiny::Error::NestedFormError;
-$Form::Tiny::Error::NestedFormError::VERSION = '2.25';
+$Form::Tiny::Error::NestedFormError::VERSION = '2.26';
 use parent -norequire, 'Form::Tiny::Error';
 
 }
@@ -61,7 +77,7 @@ use parent -norequire, 'Form::Tiny::Error';
 {
 
 	package Form::Tiny::Error::InvalidFormat;
-$Form::Tiny::Error::InvalidFormat::VERSION = '2.25';
+$Form::Tiny::Error::InvalidFormat::VERSION = '2.26';
 use parent -norequire, 'Form::Tiny::Error';
 
 	sub default_error
@@ -73,7 +89,7 @@ use parent -norequire, 'Form::Tiny::Error';
 {
 
 	package Form::Tiny::Error::Required;
-$Form::Tiny::Error::Required::VERSION = '2.25';
+$Form::Tiny::Error::Required::VERSION = '2.26';
 use parent -norequire, 'Form::Tiny::Error';
 
 	sub default_error
@@ -85,7 +101,7 @@ use parent -norequire, 'Form::Tiny::Error';
 {
 
 	package Form::Tiny::Error::IsntStrict;
-$Form::Tiny::Error::IsntStrict::VERSION = '2.25';
+$Form::Tiny::Error::IsntStrict::VERSION = '2.26';
 use Moo;
 	use Types::Standard qw(Str);
 
@@ -115,7 +131,7 @@ use Moo;
 {
 
 	package Form::Tiny::Error::DoesNotValidate;
-$Form::Tiny::Error::DoesNotValidate::VERSION = '2.25';
+$Form::Tiny::Error::DoesNotValidate::VERSION = '2.26';
 use parent -norequire, 'Form::Tiny::Error';
 
 	sub default_error
@@ -135,10 +151,11 @@ Form::Tiny::Error - form error wrapper
 =head1 SYNOPSIS
 
 	my $error = Form::Tiny::Error::DoesNotValidate->new(
-		field => 'some_field',
+		field_def => $field_def_obj,
 		error => 'some message'
 	);
 
+	my $field_def = $error->field_def; # field definition object or undef
 	my $field = $error->field; # field name or undef
 	my $data = $error->get_error; # error message or nested error object
 
@@ -171,3 +188,28 @@ which occured. These are:
 
 =back
 
+=head1 ATTRIBUTES
+
+=head2 field_def
+
+The definition of a field which had the error - an instance of L<Form::Tiny::FieldDefinition>.
+
+B<writer> I<set_field_def>
+
+B<predicate:> I<has_field_def>
+
+=head2 field
+
+Name of the field with the error. May be a label or something user-readable.
+Will be pulled from L</field_def> if not passed.
+
+B<writer> I<set_field>
+
+B<predicate:> I<has_field>
+
+=head2 error
+
+The error string.
+
+B<writer> I<set_error>
+
